@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "introductionwebenginepage.h"
 #include <QFontDatabase>
-#include <QWebEngineSettings>
 #include <QWebEngineProfile>
+#include <QWebEngineSettings>
 IntroductionWebEnginePage::IntroductionWebEnginePage(QObject *parent)
     : QWebEnginePage(parent)
 {
@@ -20,7 +20,7 @@ IntroductionWebEnginePage::IntroductionWebEnginePage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::XSSAuditingEnabled, false);
     settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
     settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, false);
-    //settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
+    // settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
 
     settings()->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, false);
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
@@ -46,8 +46,8 @@ bool IntroductionWebEnginePage::acceptNavigationRequest(const QUrl &url, Navigat
     if (url.scheme() == QLatin1String("data")) {
         return true;
     }
-    Q_UNUSED(type);
-    Q_UNUSED(isMainFrame);
+    Q_UNUSED(type)
+    Q_UNUSED(isMainFrame)
     Q_EMIT urlClicked(url);
     return false;
 }
